@@ -1,12 +1,9 @@
 import oracledb
 
+from src.mb_cruise_migration.logging.batch_error import BatchError
+from src.mb_cruise_migration.logging.migration_log import MigrationLog
 from src.mb_cruise_migration.migration_properties import MigrationProperties
 
-class BatchError(object):
-    def __init__(self, error, offset):
-        self.error = error
-        self.offset = offset
-
 
 class CruiseConnection(object):
     def __init__(self):
@@ -22,6 +19,7 @@ class CruiseConnection(object):
                 threaded=True
             )
         except Exception as e:
+            MigrationLog.log_exception(e)
             print("WARNING DB failed to connect. Script closing", e)
             raise e
 
